/*
* SILC_TAXBEN MODEL
* THE COMPONENT COMPUTES THE TAX LIABILITIES, AVERAGE AND MARGINAL AND PARTICIPATION TAX RATES
* FOR THE CURRENT TAX PARAMETERS (BEFORE REFORM) AND HYPOTHETICAL ALTERNATIVE PARAMETERS (AFTER REFORM)

* INPUTS:
* 1. DATASET wtaxbensilc.dta, with tax liabilies and ATRs derived directly from the tax information in SILC
* The dataset also classifies households into tax units for income tax purposes

* 2. Parameter values before and after reform (defined at the beginning of the dataset) - a radical re-definition of the tax system 
*    may not allow a simple substitution of different parameters, but may require a change in formulas)

* Algorithm - overview:
* 0. The algorithm runs as a stata program - can be repeated for different regimes
* 0.  Isolate incomes under different tax regimes - this has shifted to dataprocess
* - labor in formal job
* - labor under informal contract (DPP)
* - business income (main and secondary lumped together)

* 1. Compute the social security and health taxes (easier to simply re-compute what is done in dataprocess

* 2. Tax base = sum of the work and business income bases

* 3. Apply the deductions from the tax base 15,
* Be careful to whom they apply (individual, unit taxhead, household taxhead)
* 15.1) charitable contributions
* 15.3-4) mortgage interest
* 15.5) pension insurance
* 15.6) life insurance
* 15.7) labor union contributions
* 15.8) education costs
* 34.4) R&D
* other?

* 4. Compute the tax before credits (mechanical)

* 5. Tax credits 
* We define dummies for eligibility for each credit and then multiply the credit amount by the eligibility dummies
	Credits included so far: 
	a) taxpayer
	b) taxpayer spouse with low earnings
	c) child below 18
	d) child aged 18-26 who is a student
	e) taxpayer is a student
* 5.1. Define tax credit eligibilities
* 5.2. Subtract the credits 
* 5.3. The tax remains either positive or zero
* 5.4. Check eligibility for the bonus
* 5.5. Apply the bonus

* 6. Calculate the actual income tax liability (incl. bonus)
	6.1. add the bonus
	6.2 divide the income tax into work and business income


* Set-up for computing marginal tax rates (at the individual level, assuming other family members don't change behavior)
* TBA ....
******************
*/ 

* Load the data etc, parameters, computations from SILC 


* Define the program, steps 1-9
capture program drop taxcompute
program taxcompute
	args t datain dataout
	set more off
	* NEW0702 - new arguments - source file and output file - when computing MTS, we'll use datasets with 
	* income values modifies, so we run the program with different datasources
	* same applies to saving the dataset
	* for actual incomes, the input dataset is "wsilctaxben" 
	* t = tax regime (before or after reform, 0 or 1, other can be defined)
	
	use `datain', clear
	do etbparameters_`t'
	parameters `t'

	* 0. Income definitions: 
	* defined in dataprocess
	*** we need to replace ginc_i by the sum of its components for MTR/PTR calculation, because we change one of the incomes (ginc_wf or ginc_wi etc.) for MTR/PTR calculation, so we need the ginc_idefinition to be changed as well (ginc_i is used to calculate netinc for bencalculation)
	replace ginc_i = ginc_wf + ginc_wi + ginc_bm + ginc_bs 
	
	* 1. 
	* Compute social security and health taxes
	* 1a. Paid by employer, taking into account the floors and caps, distinguishing formal and informal work
	* Formal work: linear tax rate, min floor for health, max cap for both
	* Informal work: linear tax rate on income exceeding the annual exemption limit 

	* MOnths of insurance:
	* these are divided into months when the worker pays out of his earnings (mes_poj)	
	* and those when he/she pays for herself (mes_sam)
	* We cannot settle those perfectly, so for some people we assume their insurance is paid by the government for the whole year
	* If a person has earnings, the insurance is still paid
	g dmy_healthp_gov = 0
	label var dmy_healthp_gov "Dummy = health insurance paid by the government all year"
	* Health insurance by the government: children and retirees
	replace dmy_healthp_gov = 1 if pohl==1 & (vek<=18 | vek>=duchvekm_`t')
	replace dmy_healthp_gov = 1 if pohl==2 & (vek<=18 | vek>=duchvekz_`t')
	* Health insurance by government: students
	replace dmy_healthp_gov = 1 if vek>18 & vek<=26 & studium~=0
	* Health insurance by government: unemployed seeking work (rough definition for registered at unemployment office)
	replace dmy_healthp_gov = 1 if pa==5 & hled_prac~=4
	* Health insurance by government: care for children and disabled, only for women with low incomes
	* dummies - at least one child below 7, or two children below 15
	g dmy_age7 	= vek<=7
	g dmy_age15 = vek<=15
	bysort domac: egen hh_nage7  = total(dmy_age7)
	bysort domac: egen hh_nage15 = total(dmy_age15)
	* dummies - presence of a disabled in hh (use same definitions as for tax credits - the worst health status)
	g dmy_healthstat5 = zdrav_stav==5
	bysort domac: egen hh_nhealthstat5 = total(dmy_healthstat5)
	* now define the eligibility:
	replace dmy_healthp_gov = 1 if (hh_nage7 >=1 | hh_nage15>=2 | hh_nhealthstat5 >=1) & pohl==2 & vek>=18 & ginc_i<inclb
	* Health insurance by gov: collecting some pension for the whole year
	replace dmy_healthp_gov = 1 if mes_duch==12 
	
	* Define number of month of insurance for those who are not covered
	gen mes_poj= mes_zam + mes_podn + (12-min(12,mes_zam+mes_podn+mes_nez+mes_rod+mes_duch))		//number of months, when individual has to pay payroll taxes
	gen mes_sam = 0
	replace mes_sam= 12 - min(12,mes_zam+mes_podn+mes_nez+mes_rod+mes_duch)	if dmy_healthp_gov == 0 //number of months, when individual is not employed or self-employed and has to pay payroll taxes
	
	local minbaseser "minsser"
	foreach v of local minbaseser {  //minimum depends on the number of months worked
		g ind_`v'_`t' = `v'_`t'/(12/mes_zam) //division by zero for those who worked 0 months in business -> missing observations
		replace ind_`v'_`t' = 0 if `v'_`t'==.
	}
	local maxbaseser "maxsser maxhealther"
	foreach v of local maxbaseser {  //maximum does NOT depend on the number of months worked
		g ind_`v'_`t' = `v'_`t'
	}

	g ssper_wf_`t' = 0
	g healthper_wf_`t' = 0
	label variable ssper_wf_`t' "Social security insurance paid by employer, formal work, `t'"
	label variable healthper_wf_`t' "Health insurance paid by employer, formal work, `t'"

	g ssper_wi_`t' = 0
	g healthper_wi_`t' = 0 
	label variable ssper_wi_`t' "Social security insurance paid by employer, informal work, t=`t'"
	label variable healthper_wi_`t' "Health insurance paid by employer, informal work, t=`t'"

	if dmywagebilltax_`t' == 0 { 					//loop for standard social security and health insurance paid by employer (Formal work: minimum for social security participation, cap for both; Informal work: linear tax rate on income exceeding the annual exemption limit)
	*formal work
	replace ssper_wf_`t' = sser_`t' * ginc_wf	    	if ginc_wf > ind_minsser_`t'
	replace ssper_wf_`t' = sser_`t' * maxsser_`t' 		if ginc_wf > ind_maxsser_`t'
	
	replace healthper_wf_`t' = healther_`t' * ginc_wf 
	replace healthper_wf_`t' = healther_`t' * ind_maxhealther_`t' if ginc_wf > ind_maxhealther_`t'

	*informal work	
	replace ssper_wi_`t' = sser_`t'*(ginc_wi-maxiw_`t') if ginc_wi>maxiw_`t'
	replace healthper_wi_`t' = healther_`t'*(ginc_wi-maxiw_`t') if ginc_wi>maxiw_`t'
	*** This could be extended to allow some positive tax rate below the limit and set current rates to zero
	}

	else {										//loop for wage bill definition of social security and helah insurance (after JIM) (assuming caps are not binding in practice; Formal work: minimum for social security participation; Informal work: linear tax rate on income exceeding the annual exemption limit)
	*formal work
	replace healthper_wf_`t' = healther_`t'*ginc_wf if ginc_wf<=ind_maxhealther_`t' 
	replace healthper_wf_`t' = healther_`t'*maxhealther_`t'  if ginc_wf > ind_maxhealther_`t'
	
	replace ssper_wf_`t' = sser_`t' * ginc_wf		if ginc_wf > ind_minsser_`t' & ginc_wf<=ind_maxsser_`t' 
	replace ssper_wf_`t' = sser_`t' * maxsser_`t' 	if ginc_wf > ind_maxsser_`t'
	
	
	*informal work
	replace ssper_wi_`t' = sser_`t'*(ginc_wi-maxiw_`t') if ginc_wi>maxiw_`t'
	replace healthper_wi_`t' = healther_`t'*(ginc_wi-maxiw_`t') if ginc_wi>maxiw_`t'
	}

	replace healthper_wf_`t' = 0 if healthper_wf_`t' ==. 	// missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)
	replace ssper_wf_`t'     = 0 if ssper_wf_`t' ==. 		// missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)

	replace healthper_wi_`t' = 0 if healthper_wi_`t' ==. 	// missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)
	replace ssper_wi_`t'     = 0 if ssper_wi_`t' ==. 		// missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)

	* 1b. Paid by employee, taking into account the floors and caps, distinguishing formal and informal work
	* Formal work 
	
	local minbasesee "minssee"
	foreach v of local minbasesee {  //minimum depends on the number of months worked
		g ind_`v'_`t' = `v'_`t'/(12/mes_zam)  //division by zero for those who worked 0 months in business -> missing observations ->replaced in the next step (line)
		replace ind_`v'_`t' = 0 if `v'_`t'==.
	}
	local maxbasesee "maxssee maxhealthee"
	foreach v of local maxbasesee {  //maximum does NOT depend on the number of months worked
		g ind_`v'_`t' = `v'_`t'
	}
	
	gen sspee_wf_`t' = 0
	gen healthpee_wf_`t' = 0
	
	if dmyannualbase_`t' == 0 {					//loop for min/max ss and health insurance with a monthly base (before JIM) 
	g ind_minhealthee_`t' = minhealthee_`t'/(12/mes_zam)

	replace sspee_wf_`t' = ssee_`t'*ginc_wf 		if ginc_wf > ind_minssee_`t' & ginc_wf <= ind_maxssee_`t'
	replace sspee_wf_`t' = ssee_`t'*maxssee_`t' 	if ginc_wf > ind_maxssee_`t'					   

	replace healthpee_wf_`t' = healthee_`t'*ginc_wf 	    													if ginc_wf< ind_minssee_`t' & ginc_wf >0
	replace healthpee_wf_`t' = healthee_`t'*ginc_wf + (ind_minhealthee_`t'-ginc_wf)*(healthee_`t'+healther_`t') 	if ginc_wf>= ind_minssee_`t' & ginc_wf< ind_minhealthee_`t'
	replace healthpee_wf_`t' = healthee_`t'*ginc_wf										    					if ginc_wf>= ind_minhealthee_`t' & ginc_wf < ind_maxhealthee_`t' 
	replace healthpee_wf_`t' = healthee_`t' * maxhealthee_`t'								    				if ginc_wf > ind_maxhealthee_`t'
	* When the income is below social security minimum, only health insurance is paid
	* When the income is above social security minimum and below health insurence minimum, employees pay both health and social security insurance (employees pay social security and health insurence derived from their income, on top of that, they pay employee and employer health insurance from difference between minimum of health insurance and their income)
	* When the income is between the thresholds, employees pay social security and health insurence derived from their income
	* When the income is above social security maximum and below health insurence maximum, , employees pay social security insurence from the treshold and health insusence from the income  
	* When the income is above both the thresholds (social security and health insurance), employees pay social security insurance from the social security treshold and health insusence from health insurance treshold
	* Adding the insurance for the months when the employee is not working but must pay the minimum
	g healthpee_wfadd_`t'  = (healthee_`t'+healther_`t')*mes_sam*(scalar(minhealthee_`t')/12) if mes_podn<=mes_zam			//health insurance is increased for payments, which are paid by employee when not working
	replace healthpee_wf_`t' = healthpee_wf_`t'+ healthpee_wfadd_`t' if mes_podn<=mes_zam
	}

	else {			//loop for min/max ss and health insurance with an annual base (after JIM)
	g       ind_minhealthee_`t' = 0
	replace ind_minhealthee_`t' = minhealth_coef_`t'*mwage_`t'*(mes_zam+ mes_sam) if mes_podn+mes_podn_bs==0	//minimum depends on minimal wage, number of months, when individual is not "insured by state"  

	replace sspee_wf_`t' = ssee_`t' * ginc_wf		if ginc_wf > ind_minssee_`t' & ginc_wf <= ind_maxssee_`t'
	replace sspee_wf_`t' = ssee_`t' * maxssee_`t' 	if ginc_wf > ind_maxssee_`t'		   

	replace healthpee_wf_`t' = healthee_`t' * (ginc_wf+(ind_minhealthee_`t'-minhealth_coef_`t'*ginc_wf))	if minhealth_coef_`t'*ginc_wf< ind_minhealthee_`t' & ginc_wf >=0 & mes_podn+mes_podn_bs==0
	replace healthpee_wf_`t' = healthee_`t' *  ginc_wf														if minhealth_coef_`t'*ginc_wf< ind_minhealthee_`t' & ginc_wf >0 & mes_podn+mes_podn_bs>0 //missing u mes_podn vpodn
	replace healthpee_wf_`t' = healthee_`t' *  ginc_wf 	    												if minhealth_coef_`t'*ginc_wf>= ind_minhealthee_`t' & ginc_wf< ind_maxhealthee_`t'
	replace healthpee_wf_`t' = healthee_`t' * maxhealthee_`t'												if ginc_wf> ind_maxhealthee_`t'
	
	* Employee participate onn social security only if they are above social security minimum
	* Flat rates and caps are applied for both health and social security
	}

	label variable sspee_wf_`t' "Social security insurance paid by employee, formal work, `t'"
	label variable healthpee_wf_`t' "Health security insurance paid by employee, formal work, `t'"

	* Informal work
	g sspee_wi_`t' = 0
	g healthpee_wi_`t' = 0
	
	replace sspee_wi_`t' = ssee_`t'*(ginc_wi-maxiw_`t') if ginc_wi>maxiw_`t'
	replace healthpee_wi_`t' = healthee_`t'*(ginc_wi-maxiw_`t') if ginc_wi>maxiw_`t'
	label variable sspee_wi_`t' "Social security insurance paid by employee, informal work, `t'"
	label variable healthpee_wi_`t' "Health insurance paid by employee, informal work`t'"
	*** This could be extended to allow some positive tax rate below the limit and set current rates to zero
	
	replace healthpee_wf_`t' = 0 if healthpee_wf_`t' ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)
	replace sspee_wf_`t'     = 0 if sspee_wf_`t' ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)

	replace healthpee_wi_`t' = 0 if healthpee_wi_`t' ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)
	replace sspee_wi_`t'     = 0 if sspee_wi_`t' ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)

	* 1.c summing the taxes on work income
	* health and social security - by employee/employer
	g healthpee_w_`t' = healthpee_wf_`t' + healthpee_wi_`t' 
	g healthper_w_`t' = healthper_wf_`t' + healthper_wi_`t' 
	g sspee_w_`t' = sspee_wf_`t' + sspee_wi_`t' 
	g ssper_w_`t' = ssper_wf_`t' + ssper_wi_`t' 
	
	* employee and employer together, by health/social security
	g healthp_w_`t' = healthpee_w_`t' + healthper_w_`t' 
	g ssp_w_`t' = sspee_w_`t' + ssper_w_`t' 
	
	* payroll taxes by employee/employer
	g payrolltaxee_w_`t' = healthpee_w_`t' + sspee_w_`t'
	g payrolltaxer_w_`t' = healthper_w_`t' + ssper_w_`t'
	
	* all payroll taxes on work income
	g payrolltax_w_`t' = payrolltaxee_w_`t' + payrolltaxer_w_`t'
	
	label var healthpee_w_`t'  "Health insurance paid by employee, `t'"
	label var healthper_w_`t'  "Health insurance paid by employer, `t'" 
	label var sspee_w_`t' 		"Social security insurance paid by employee, `t'"
	label var ssper_w_`t'		"Social security insurance paid by employer, `t'" 
	label var healthp_w_`t' 	"Health insurance on work income (by employee and employer), `t'"
	label var ssp_w_`t' 		"Social security insurance on work income (by employee and employer), `t'" 
	label var payrolltaxee_w_`t' "All payroll taxes paid by employee, `t'"
	label var payrolltaxer_w_`t' "All payroll taxes paid by employer, `t'"
	label var payrolltax_w_`t' "All payroll taxes on work income (by employee and employer), `t'"

	* 1d. Paid on business income, taking into account the floor and cap, and the fraction counted as "vymerovaci zaklad"
	* Computed separately for main and secondary business, with monthly floors
	*** Main business income: the minimun floors apply
	*** Secondary business income: linear schedule starting at zero
	*** The final variable is payrolltaxb_`t', that is, total payroll taxes on business income (main and secondary combined)
	
	* Define the individual min and max payroll tax bases (depending on the number of months in business"
	
	gen ssped_bm_`t' = 0
	gen ssped_bs_`t' = 0
	gen healthped_bm_`t' = 0
	gen healthped_bs_`t' = 0
	label var ssped_bm_`t' "Social security contribution paid on main business income, t=`t'"
	label var ssped_bs_`t' 	"Social security contribution paid on secondary business income, t=`t"
	label var healthped_bm_`t'	"Health insurance paid on main business income"
	label var healthped_bs_`t' 	"Health insurance paid on secondary business income"

	if dmyannualbase_`t' == 0 {					//loop for min/max base with monthly assessment (before JIM)
	* Set individual-specific minimum and maximum ss and health bases, which depend on the months in business
	local minbasesed "minssed_bm minssed_bs minhealthed" //minima for main business and secondary
	foreach v of local minbasesed {  //minimum depends on the number of months in business - main and secondary never overlap in SILC
		g ind_`v'_`t' = `v'_`t'/(12/(mes_podn+mes_podn_bs)) //division by zero for those who worked 0 months in business -> missing observations
		replace ind_`v'_`t' = 0 if ind_`v'_`t'==.
	}
	replace ind_minhealthed_`t' = 0 if ginc_w > minhealthee_`t' // set to zero if sufficient employment income
		
	local maxbasesed "maxssed maxhealthed"
	foreach v of local maxbasesed {   //maximum does not depend on the number of months worked
		g ind_`v'_`t' = `v'_`t'
	}
	//For main business income - (individual) thresholds apply
	replace ssped_bm_`t' = tbassed_`t'*ssed_`t'*ginc_bm		
	replace ssped_bm_`t' = ssed_`t'*ind_minssed_bm_`t' if tbassed_`t'*ginc_bm < ind_minssed_bm_`t' & ginc_bm >0
	replace ssped_bm_`t' = ssed_`t'*ind_maxssed_`t' if tbassed_`t'*ginc_bm > ind_maxssed_`t'
	/*
	In the case of lower threshold, checked whether ginc_bm!=0 so that the minimum insurance assigned only
	to those who had some income from main business. 
	There were 0 observations in 2010 sample with negative ginc_bm.
	*/	

	replace healthped_bm_`t' = tbassed_`t'*healthed_`t'*ginc_bm			
	replace healthped_bm_`t' = healthed_`t'*ind_minhealthed_`t' if tbassed_`t'*ginc_bm < ind_minhealthed_`t' & ginc_bm >0
	replace healthped_bm_`t' = healthed_`t'*ind_maxhealthed_`t' if tbassed_`t'*ginc_bm > ind_maxhealthed_`t'
	* Adding the insurance for the month when the self-employed does not run the business but must pay the minimum
	replace healthped_bm_`t' = healthped_bm_`t'+ healthed_`t' * mes_sam*(minhealthee_`t'/12)	if mes_podn>mes_zam						//health insurance is increased for payments, which are paid by self-employed when not working

	//For secondary business income - general formula with individual minimum threshold (although it was zero in most years for ss)
	replace ssped_bs_`t' = tbassed_`t'*ssed_`t'*ginc_bs
	replace ssped_bs_`t' = ssed_`t'*ind_minssed_bs_`t' if tbassed_`t'*ginc_bs < ind_minssed_bs_`t' & ginc_bs >0
	replace healthped_bs_`t' = tbassed_`t'*healthed_`t'*ginc_bs
	replace healthped_bs_`t' = healthed_`t'*ind_minhealthed_`t' if tbassed_`t'*ginc_bs < ind_minhealthed_`t' & ginc_bs >0
	}

	else {					//min/max base with annual assessment (after JIM)
	g       ind_minssed_`t' = 0
	replace ind_minssed_`t' = minssed_bm_coef_`t'*mes_podn *awage_`t'							if mes_podn>0			//minimum depends on average wage in the economy, type of self-employment and number of months of self-employment
	replace ind_minssed_`t' = minssed_bs_coef_`t'*mes_podn_bs*awage_`t'+ind_minssed_`t'			if mes_podn_bs>0			//minimum depends on average wage in the economy, type of self-employment and number of months of self-employment		
	
	g ind_minhealthed_`t'		= 0
	replace ind_minhealthed_`t'	= minhealth_coef_`t'*mwage_`t'*(mes_zam+mes_podn+ mes_sam) 		if mes_podn+mes_podn_bs>0	//minimum depends on minimal wage, number of months, when individual is not "insured by state"  
	replace ind_minhealthed_`t'	= minhealth_coef_`t'*mwage_`t'*(mes_zam+mes_podn)				if mes_podn+mes_podn_bs>0 & vek1zam+1>=vek
	g ind_maxssed_`t' 			= maxssed_`t'  																			//maximum does not depend on the number of months worked
	g ind_maxhealthed_`t' 		= maxhealthed_`t'

	replace ssped_bm_`t' = ssed_`t'*ginc_bm															//flat rate, floor and cap is applied (if total income - self-employed plus employee income -is above cap, first self-employed income is reduced, if it is not sufficient, also employee income is reduced)
	replace ssped_bm_`t' = ssed_`t'*ind_minssed_`t'*(ginc_bm/(ginc_bm+ginc_bs))			  		if ginc_bm+ginc_bs         < ind_minssed_`t'
	replace ssped_bm_`t' = ssed_`t'*max(0, ind_maxssed_`t'-ginc_wf)*(ginc_bm/(ginc_bm+ginc_bs)) if ginc_bm+ginc_bs+ginc_wf > ind_maxssed_`t'

	replace ssped_bs_`t' = ssed_`t'*ginc_bs
	replace ssped_bs_`t' = ssed_`t'*ind_minssed_`t'*(ginc_bs/(ginc_bm+ginc_bs))			  		if ginc_bm+ginc_bs        < ind_minssed_`t'
	replace ssped_bs_`t' = ssed_`t'*max(0, ind_maxssed_`t'-ginc_wf)*(ginc_bs/(ginc_bm+ginc_bs)) if ginc_bm+ginc_bs+ginc_wf> ind_maxssed_`t'

	replace healthped_bm_`t' = healthed_`t'*ginc_bm													//flat rate, floor and cap is applied (if total income - self-employed plus employee income -is above cap, first self-employed income is reduced, if it is not sufficient, also employee income is reduced)
	replace healthped_bm_`t' = healthed_`t'*(ind_minhealthed_`t'-minhealth_coef_`t'*ginc_wf)*(ginc_bm/(ginc_bm+ginc_bs))   	if ginc_bm+ginc_bs+minhealth_coef_`t'*ginc_wf<ind_minssed_`t'
	replace healthped_bm_`t' = healthed_`t'*max(0, ind_maxhealthed_`t'-ginc_wf)*(ginc_bm/(ginc_bm+ginc_bs)) 				if ginc_bm+ginc_bs+ginc_wf> ind_maxhealthed_`t'

	replace healthped_bs_`t' = healthed_`t'*ginc_bs
	replace healthped_bs_`t' = healthed_`t'*(ind_minhealthed_`t'-minhealth_coef_`t'*ginc_wf)*(ginc_bs/(ginc_bm+ginc_bs))   	if ginc_bm+ginc_bs+minhealth_coef_`t'*ginc_wf<ind_minssed_`t'
	replace healthped_bs_`t' = healthed_`t'*max(0, ind_maxhealthed_`t'-ginc_wf)*(ginc_bs/(ginc_bm+ginc_bs)) 				if ginc_bm+ginc_bs+ginc_wf> ind_maxhealthed_`t'
	}

	replace healthped_bm_`t' = 0 if healthped_bm_`t' ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)
	replace ssped_bm_`t'     = 0 if ssped_bm_`t' ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)

	replace healthped_bs_`t' = 0 if healthped_bs_`t' ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)
	replace ssped_bs_`t'     = 0 if ssped_bs_`t' ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)
	* END CHECK WITH JS - NOT NEEDED NOW
	
	* 1.e. Summing up the payroll taxes on business income
	* Social security and health
	g healthp_b_`t'	= healthped_bm_`t' + healthped_bs_`t'
	g ssp_b_`t' 	= ssped_bm_`t' + ssped_bs_`t' 
		
	* All payroll taxes on main/secondary business income
	g payrolltaxed_bm_`t' = ssped_bm_`t' + healthped_bm_`t'
	g payrolltaxed_bs_`t' 	= ssped_bs_`t' + healthped_bs_`t'
	
	* All payroll taxes on business income
	g payrolltax_b_`t' 	= ssp_b_`t' + healthp_b_`t'

	label var healthp_b_`t' 		"Health insurance on business income, `t'" 
	label var ssp_b_`t' 			"Social security insurance on business income, `t'"
	label var payrolltaxed_bm_`t'	"Payroll taxes paid on main business income, `t'"
	label var payrolltaxed_bs_`t'	"Payroll taxes paid on secondary business income, `t'"
	label var payrolltax_b_`t'		"All payroll taxes paid on business income, `t'"
	
	* 1f. Summing all payroll taxes
	g healthp_i_`t' 	= healthp_w_`t' + healthp_b_`t'
	g ssp_i_`t' 		= ssp_w_`t' + ssp_b_`t'
	g payrolltax_i_`t' 	= payrolltax_w_`t' + payrolltax_b_`t' //generating total payroll tax (on business + work income)
	
	label var healthp_i_`t' 	"Total health insurance (on work + business income), `t'" 
	label var ssp_i_`t' 		"Total social security insurance (on work + business income), `t'"  
	label var payrolltax_i_`t' 	"Total payroll tax (on work + business income), `t'"
	
	* 3. Partial Tax bases (for the income tax)
	* Depending on the regime, it is either the supergross or the gross wage for the work income plus the business income
	* The regime is indicated by a dummy varible dmygross (=1 for gross, 0 for supergross)
	* ENDNEWLD
	
	*capture drop sginc_w_`t'
	*capture drop sginc_b_`t'
	g sginc_w_`t' = ginc_wf + ginc_wi + payrolltaxer_w_`t'
	g sginc_b_`t' = ginc_bm + ginc_bs
	g sginc_i_`t'	= sginc_w_`t'+ sginc_b_`t' 
	label var sginc_w_`t' "Super-gross income from work, t=`t' "
	label var sginc_b_`t' "Super-gross income from business, t=`t' "
	label var sginc_i_`t'	"Total economic income (super-gross), t=`t' "
	
	* Define the taxbases, separately for work and business income and then sum up
	* NEWLD
	* Tax base on work: include formal work income for now, the informal after you check the exact status
	g tb_w_`t' = 0
	if dmygross_`t' == 0 {
		replace tb_w_`t'	= sginc_w_`t' if sginc_w_`t' >0
	}
	else {
		replace tb_w_`t'	= ginc_wf + ginc_wi if (ginc_wf>0 | ginc_wi>0)
	}
	* ENDNEWLD
	g tb_b_`t'  = 0
	replace tb_b_`t'	= sginc_b_`t' if sginc_b_`t' > 0
	g tb_i_`t' 	= tb_w_`t' + tb_b_`t'
	label var tb_w_`t'	"Tax base from work income ( 6), `t'"
	label var tb_b_`t'	"Tax base from business income ( 7), `t'"
	label var tb_i_`t' 	"Tax base (line 42 on the income tax return), `t'"
	
	* 5. Deductions
	* 15.1 - charitable contributions
	* no info directly in SILC
	* SRU has "prispevky organizacim"
	g dedcharity_`t' = 0
	
	* 15.3-4 - mortgage interest (and other housing loans)
	* The amount of the mortgage interest paid is already imputed in dataprocess (with many assumptions)
	* here we only apply the tax rule on deduction
	
	g dedmortgage_`t' = 0
	replace dedmortgage_`t' = min(mortg_interest,mortg_cap_`t') if taxhead==1
	label var dedmortgage_`t'	"Mortgage interest deduction (imputed), t = `t'"
			
	* 15.5 Pension insurance (IIIrd pillar, volutary)
	* Directly reported in SILC (Kc/year, can easily be imputed)
	* amount exceeding 6000, but the deduction is capped at 12,000)
	g dedpension_`t' 	= 0
	replace dedpension_`t' = min(max(penz_poj-6000,0),12000)
	label var dedpension_`t' "Pension insurance deduction, t = `t'"
	
	* Other deductions (not imputed)
	g dedlife_`t' 		= 0
	g dedunion_`t' 		= 0
	g dededuc_`t' 		= 0
	g dedrad_`t'		= 0
	g dedother_`t' 		= 0

	* Tax base after deductions:
	g tbreduced_`t' = max(0, tb_i_`t' - dedcharity_`t' - dedmortgage_`t' - dedpension_`t' - dedlife_`t' - dedunion_`t' - dededuc_`t' - dedrad_`t' - dedother_`t')
	label var tbreduced_`t' "Tax based (reduced) after deductions, `t' "

	* 4. Income tax before credits:
	* Compute it as if there were several brackets, despite the fact that there are not
	* Dummies for each bracket:
	g dbrkt0_`t' = tbreduced_`t' == 0
	g dbrkt1_`t' = tbreduced_`t' >  0 & tbreduced_`t'< brkt1_`t'
	g dbrkt2_`t' = tbreduced_`t' >= brkt1_`t' & tbreduced_`t' < brkt2_`t'
	g dbrkt3_`t' = tbreduced_`t' >= brkt2_`t' & tbreduced_`t' < brkt3_`t'
	g dbrkt4_`t' = tbreduced_`t' >= brkt3_`t'
	label var dbrkt0_`t' "Dummy for zero tax bracket (zero tax base after deduction), `t' "
	label var dbrkt1_`t' "Dummy for the 1st tax bracket, `t' "
	label var dbrkt4_`t' "Dummy for the 4th (top) tax bracket, `t' "
	
	g inctaxbc_`t' = 0
	replace inctaxbc_`t' = tbreduced_`t'*taxr1_`t' if dbrkt1_`t' == 1
	replace inctaxbc_`t' = brkt1_`t'*taxr1_`t' + (tbreduced_`t'-brkt1_`t')*taxr2_`t' if dbrkt2_`t' == 1
	replace inctaxbc_`t' = brkt1_`t'*taxr1_`t' + (brkt2_`t' - brkt1_`t')*taxr2_`t' + (tbreduced_`t'-brkt2_`t')*taxr3_`t' if dbrkt3_`t' == 1
	replace inctaxbc_`t' = brkt1_`t'*taxr1_`t' + (brkt2_`t' - brkt1_`t')*taxr2_`t' + (brkt3_`t' - brkt2_`t')*taxr3_`t' + (tbreduced_`t'-brkt3_`t')*taxr4_`t' if dbrkt4_`t' == 1

	* Add the special surcharge introduced in 2013
	* parameters contain a dummy variable indicating whether the surcharge exists - split the computation for a regime with and without the surcharge
	* 
	if dmyscharge_`t' == 0 {
		g inctaxscharge_`t' = 0
	}
	else {
		g inctaxscharge_`t' = max(0, ginc_wf + ginc_bm + ginc_bs - brktscharge_`t')*taxscharge_`t'
	}
	replace inctaxbc_`t' = 	inctaxbc_`t' + inctaxscharge_`t'
	label var inctaxbc_`t' "Income tax before credits, t=`t' "
	
	* 5. Tax credits / tax bonus
	*** 5.1. Generating credit eligibility dummies ***
	//(unless noted otherwise, 1 means that a person is eligible, 0 means that the person is not eligible)
	
	/* 5.1.a Taxpayer tax credit
	Everybody's eligible until 2015 reform
	After that, only people with income below limit (p_limit)
	Modeled generally, but for years without the limit the limit is set arbitrarily high
	*/
	
	g delpex_`t' = 1
	replace delpex_`t' = 0 if tb_i_`t' > p_limit_`t'
		
	/*
	5.1.b. Spouse with low earnings tax credit
	
	sp_limit_`t' - scalar, max annual income of spouse so that spouse tax credit eligibility arises,
	defined in etbparameters.do. A person is eligible if he/she is married to a spouse living in the same household
	if the spouse earns no more than sp_limit per year.
	
	We count the number of people who live in a married couple in every tax unit (0 to 2). If this equals 2, there
	is potential eligibility. Then, we count the number of such people whose income is lower than the limit sp_limit0.
	If the result is 2 (both have low income), both members of the couple are eligible. If the result is 1,
	only the person with the income above the limit is eligible (this will also be the head of tax unit,
	because it is always the person with the highest income within tax unit). If the 
	result is 0, nobody is eligible.
	*/
	gsort taxunit ginc_i

	by taxunit: egen TUpairtu=count(TUpair) //number of members of married couple in a tax unit
	//the suffix tu means that the value is the smae of all members of a tax unit (similar to hh suffix).
	gen TUpairlowinc_`t' = 1 if TUpair == 1 & ginc_i< sp_limit_`t' //1 for low income members of married couple, . for others
	by taxunit: egen TUpairlowinctu_`t'=count(TUpairlowinc) //number of low income members of married couple in a tax unit

	gen		delspex_`t' = 0
	//The case when there is only one low income member of married couple
	replace delspex_`t' = 1 if TUpair == 1 & TUpairtu == 2 & TUpairlowinctu_`t' == 1 & taxhead == 1
	//The case when both members of the couple have low income nad thus both are eligible
	replace delspex_`t' = 1 if TUpair == 1 & TUpairtu == 2 & TUpairlowinctu_`t' == 2

	/*
	5.1.c. and 5.1.d. Child and child-student tax credit
	We take it as given that the credits are linear in the number of children and that the age limits
	are given. A tax reform may change these, would have to be reprogrammed

	The number of children on which a tax payer is eligible to draw the tax credit. These are children
	below 18 years of age, or aged 18-26 and still studying. They are treated the same way in income tax law,
	but we distinguish the two.
	
	Unlike the previous dummies, these variables contain the number of children, not just 0/1 values. The positive values
	are assigned only to heads of tax units, not to all members of household.
	*/
	
	gen child18 = 1 if vek < 18
	by taxunit: egen child18tu = count(child18)
	gen delchex_`t' = child18tu * taxhead //taxhead is 1 if a person is head of tax unit, 0 otherwise

	gen student1826 = 1 if vek >= 18 & vek < 26 & studium > 0
	by taxunit: egen student1826tu = count(student1826)
	generate delchexst_`t' = student1826tu * taxhead
	
	/*
	5.1.e. Student tax credit
	- credit if taxpayer is a student younger than 26 years. 
	- Also would be eligible if he was a doctoral student younger than 28 years.
	However, that applies only to presence form of study and we don't have data on the form of study,
	so we neglect this possibility.
	*/
	gen delstex_`t' = 0
	replace delstex_`t' = 1 if (studium > 0 & vek<26)
	
	//dropping temporary variables needed for generating credit eligibility dummies
	drop TUpairlowinc_`t' TUpairlowinctu_`t' child18 child18tu student1826 student1826tu
	
	// label the credit eligibility dummies
	label var delpex_`t'  	"Eligible for taxpayer (own) tax credit, `t' "
	label var delspex_`t' 	"Eligible for spouse tax credit, `t' "
	label var delstex_`t' 	"Eligible for student tax credit, `t' "
	label var delchex_`t'	"Number of children aged < 18 eligible for child tax credit, `t' "
	label var delchexst_`t' "Number of children aged 18-26 and studying eligible for child tax credit, `t' "
	
	*5.1.f. Tax credit for ZTP/P taxpayer
	gen delpzptex_`t' = (zdrav_stav==5)

	*5.1.g Tax credit for taxpayer with disability pension
	* we cannot distinguish first and second from third degree in the data, so lets assume that those that have zdrav_stav==5 (worse) have third degree, others have first or second
	gen delpinv12ex_`t' = (dduch==3 & zdrav_stav!=5) 
	gen delpinv3ex_`t' 	= (dduch==3 & zdrav_stav==5)

	*5.1.h Tax credit for spouse with ZTP/P
	gsort taxunit ginc_i
	* dummy equal to one if taxhead's spouse is ZTP and low income
	gen nonheadZTPlowinc_`t' = 1 	if TUpair == 1 & zdrav_stav==5 & ginc_i < sp_limit_`t' & taxhead!=1 //1 for non-head ZTP/P member of a couple (only if wife)
	by taxunit: egen nonheadZTPlowinctu_`t' = count(nonheadZTPlowinc_`t') //number of low inc ZTP/P non-head members of married couple
	* dummy equal to one if non-taxhead's spouse is ZTP and low income
	gen headZTPlowinc_`t' = 1 		if TUpair == 1 & zdrav_stav==5 & ginc_i < sp_limit_`t' & taxhead==1 //1 for non-head ZTP/P member of a couple (only if wife)
	by taxunit: egen headZTPlowinctu_`t' = count(headZTPlowinc_`t') //number of low inc ZTP/P non-head members of married couple
	* dummy for eligibility for the tax credit
	gen		delsztpex_`t' = 0
	* assign tax credit to taxhead
	replace delsztpex_`t' = 1 if TUpair == 1 & TUpairtu == 2 &  taxhead == 1 & nonheadZTPlowinctu_`t'==1 //assign credit to taxhead if spouse is ZTP and low income
	* assign tax credit to taxhead's spouse
	replace delsztpex_`t' = 1 if TUpair == 1 & TUpairtu == 2 &  taxhead != 1 & headZTPlowinctu_`t'==1
	
	*5.1.i Tax credit for child with ZTP/P
	gen childZTP = 1 if (vek < 18 | (vek >= 18 & vek < 26 & studium > 0)) & zdrav_stav==5
	by taxunit: egen childZTPtu = count(childZTP)
	gen delchztpex_`t' = childZTPtu * taxhead //assign this tax credit to taxhead
			
	* 5.2. Subtract the credits from the income tax
	* The tax after credits must be non-negative
	g inctaxac_`t' = max(0, inctaxbc_`t' - pex_`t'*delpex_`t' -  spex_`t'*delspex_`t' - stex_`t'*delstex_`t' - chex_`t'*delchex_`t' - chex_`t'*delchexst_`t' - delpzptex_`t'*pztpex_`t' - delpinv12ex_`t'*pinv12ex_`t' - delpinv3ex_`t'*pinv3ex_`t' - delsztpex_`t'*sztpex_`t' - delchztpex_`t'*chztpex_`t') 
	label var inctaxac_`t' "Income tax after credits, _`t' "
	
	* 5.3. Define the dummy for bonus eligibilty
	* - Is eligible for either child tax credit
	* - The child tax credits exceed the tax after all credits except child credits by at least the min tax bonus
	* - Has earned income above the floor for claiming the bonus
	g delbon_`t' = (delchex_`t'>0 | delchexst_`t'>0) & (chex_`t'*delchex_`t' + chex_`t'*delchexst_`t' + delchztpex_`t'*chztpex_`t' - mintbon_`t' > max(0,inctaxbc_`t' - pex_`t'*delpex_`t' -  spex_`t'*delspex_`t' - stex_`t'*delstex_`t'- delpzptex_`t'*pztpex_`t' - delpinv12ex_`t'*pinv12ex_`t' - delpinv3ex_`t'*pinv3ex_`t' - delsztpex_`t'*sztpex_`t')) & (ginc_i>=floortbon_`t')
	label var delbon_`t' "Eligible for tax bonus, `t'"
	
	* 5.4. Compute the bonus
	*Bonus: Diff bw the child credits and tax after all credits except child credits, 
	g bonus_`t' = delbon_`t' * (min(maxtbon_`t', chex_`t'*delchex_`t' + chex_`t'*delchexst_`t' + delchztpex_`t'*chztpex_`t' - max(0, inctaxbc_`t' - pex_`t'*delpex_`t' -  spex_`t'*delspex_`t' - stex_`t'*delstex_`t'- delpzptex_`t'*pztpex_`t' - delpinv12ex_`t'*pinv12ex_`t' - delpinv3ex_`t'*pinv3ex_`t' - delsztpex_`t'*sztpex_`t')))
	label var bonus_`t'  "Tax bonus, `t' "
	
	* 6. Final (net) income tax liability, after adding the bonus (different calculation for those claiming the bonus and those not)
	* 6.1. Definition consistent with the inctaxc variable defined in etbdataprocess
	g inctax_i_`t' = inctaxac_`t'*(1-delbon_`t') + (inctaxac_`t' - bonus_`t')*delbon_`t'
	label var inctax_i_`t' "Income tax liability, `t' "
	
	/*
	* 6.2. Dividing the income tax into tax on work and business income
	useful for analytical puposes
	use the ratio of the tax bases for work and business income
	*/
	gen ratio_`t'	 = tb_w_`t'/tb_i_`t'
	gen inctax_w_`t' = ratio_`t'*inctax_i_`t'
	gen inctax_b_`t' = (1-ratio_`t')*inctax_i_`t'
	replace inctax_w_`t' = inctax_i_`t' if ratio_`t' ==.
	replace inctax_b_`t' = 0 if ratio_`t' ==.
	label var ratio_`t'		"Work income tax base as share of total income tax base, `t'"
	label var inctax_w_`t'	"Income tax liability on work income, `t'"
	label var inctax_b_`t'	"Income tax liability on business income, `t'"
	
	* 7.1.  Total taxes on income (income tax plus payroll - hence not including social benefits and consumption taxes)
	gen totaltax_w_`t' 	= inctax_w_`t' + payrolltax_w_`t'
	gen totaltax_b_`t' 	= inctax_b_`t' + payrolltax_b_`t'
	gen totaltax_i_`t' 	= totaltax_w_`t' + totaltax_b_`t'
	label var totaltax_b_`t' 	"Total taxes on business income, `t'"
	label var totaltax_w_`t' 	"Total taxes on work income, `t'"
	label var totaltax_i_`t' 	"Total taxes on work and business incomes, `t'"
	
	*** Taxes summed at the hh level, also separately for income tax and payroll taxes
	foreach v of varlist totaltax_w_`t' totaltax_b_`t' totaltax_i_`t' inctax_i_`t' payrolltax_i_`t' {
		bysort domac: egen hh`v' = total(`v')
	}
	label var hhtotaltax_i_`t' 		"Total household taxes on work and business income, `t'"
	label var hhinctax_i_`t'		"Household income taxes on work and business income, `t'"
	label var hhpayrolltax_i_`t'  	"Household payroll taxes on work and business income, `t'"
	
	* 8. Total after tax income (from both work and business)
	gen netinc_`t' = ginc_i - inctax_i_`t' - payrolltax_b_`t' - payrolltaxee_w_`t' 
	bysort domac: egen hhaftertinc_`t' = total(netinc_`t')
	label var netinc_`t'	"Net income (business plus work), `t'"
	label var hhaftertinc_`t' "Household after-tax income, `t'" 
	cd output_`t'
	save `dataout', replace
	cd ..
end




